<?php /* -*- coding: utf-8 -*- */

/** \file uneOPiCitation.php
 * (October 25, 2015)
 *
 * \brief
 * Little Web application to display one quotation (from OPiCitations)
 * http://www.opimedia.be/OPiCitations/uneOPiCitation.php
 *
 * May be used in an iframe to include in another Web page.
 *
 * Piece of OPiQuotations.
 * https://bitbucket.org/OPiMedia/opiquotations
 *
 * GPLv3 --- Copyright (C) 2014, 2015 Olivier Pirson
 * http://www.opimedia.be/
 *
 * @package OPiCitations
 */

require_once 'OPiQuotations/log.inc';

#DEBUG
if (true) {
  // Development configuration
  ini_set('display_errors', 'stdout');
  ini_set('display_startup_errors', 1);
  ini_set('html_errors', 1);

  error_reporting(-1);

  assert_options(ASSERT_ACTIVE, true);
  assert_options(ASSERT_WARNING, true);
  assert_options(ASSERT_BAIL, true);
}
else {
#DEBUG_END
  // Production configuration
  ini_set('display_errors', 'stderr');
  ini_set('display_startup_errors', 0);
  ini_set('html_errors', 0);

  error_reporting(-1);

  assert_options(ASSERT_ACTIVE, false);
  assert_options(ASSERT_WARNING, false);
  assert_options(ASSERT_BAIL, false);

  set_error_handler('\OPiQuotations\error_handler');
#DEBUG
}
#DEBUG_END

mb_internal_encoding('UTF-8');
mb_regex_encoding('UTF-8');
mb_http_output('UTF-8');
mb_detect_order('UTF-8');


require_once 'OPiQuotations/OPiQuotations.inc';

$opiquotations = new OPiQuotations\OPiQuotations();


// Get quotation
if (isset($_GET['id'])) {  // specific quotation
  // GET correct id parameter
  $id = (int)$_GET['id'];

  $quot = ((string)$id === $_GET['id']
           ? $opiquotations->quotation_by_id($id)
           : null);

  if ($quot === null) {  // incorrect argument or quotation not founded
    header('Location: http://'.$_SERVER['HTTP_HOST'].$_SERVER['PHP_SELF']);

    exit;
  }

  unset($id);
}
else {                     // random quotation
  $quot = $opiquotations->quotations_by_random()[0];
}


// Init other informations
$title = 'une OPiCitations n°'.$quot->id().' &mdash; Dictionnaire de plus de 3000 citations';

$desc = 'une OPiCitation n°'.$quot->id().' :
'.htmlspecialchars($quot->to_text());

$desc_open_graph = OPiQuotations\html_text_cut($desc, 300);
$desc = OPiQuotations\html_text_cut($desc, 160);


// Prepare keywords from quotation
$keywords = ['citation', 'citations', 'maxime', 'maximes', 'proverbe', 'proverbes', 'littérature', 'français'];

$i = 0;
foreach ([$quot->subject(), ($quot->is_maxim()
                             ? $quot->nation()
                             : $quot->author()), $quot->work()] as $keyword) {
  if ($keyword !== null) {
    if ($i < 2) {  // if subject, nation/author then also add pieces
      $a = explode(' ', $keyword);
      if (count($a) > 1) {
        $a[] = $keyword;
      }
    }
    else {
      $a = [$keyword];
    }

    foreach ($a as $keyword) {
      $keywords[] = htmlspecialchars($keyword);
    }

    unset($a);
  }

  ++$i;
}

unset($i);
unset($keyword);


// Set URL
$url_site = 'http://'.$_SERVER['HTTP_HOST'].dirname($_SERVER['PHP_SELF']).'/';
$url = $url_site.basename($_SERVER['PHP_SELF']).'?id='.$quot->id();

?><!DOCTYPE html>
<html lang="fr">
  <head>
    <meta http-equiv="Content-Type" content="text/html; charset=UTF-8">

    <meta name="viewport" content="width=device-width, initial-scale=1">

    <meta name="author" content="Olivier Pirson">
    <meta name="description" content="<?php echo $desc; ?>">
    <meta name="keywords" content="<?php echo implode(',', $keywords); ?>">
    <meta name="keywords" lang="en" content="quotation,quotations,maxim,maxims,proverb,proverbs,literature,French">

    <title><?php echo $title; ?></title>

    <link rel="stylesheet" type="text/css" href="public/css/oneOPiQuotation.min.css">

    <script type="text/javascript">window.___gcfg = {lang: 'fr', parsetags: 'explicit'};</script>
    <script type="text/javascript" src="http://platform.twitter.com/widgets.js" async="async"></script>
    <script type="text/javascript" src="http://connect.facebook.net/fr_FR/sdk.js" async="async"></script>
    <script type="text/javascript" src="https://apis.google.com/js/platform.js" async="async"></script>
    <script type="text/javascript" src="public/js/oneOPiQuotation.automatic-min.js" async="async"></script>

    <link rel="icon" type="image/x-icon" href="public/img/oneOPiQuotation-32x32.ico">

    <link rel="canonical" href="<?php echo $url; ?>">

    <meta property="og:image" content="<?php echo $url_site; ?>public/img/oneOPiQuotation<?php

if ($quot->is_maxim()) {
  echo '-maxim';
}

?>-256x256-t.png">
    <meta property="og:description" content="<?php echo $desc_open_graph; ?>">
    <meta property="og:title" content="<?php echo $title; ?>">
    <meta property="og:type" content="website">
    <meta property="og:url" content="<?php echo $url; ?>">

    <meta name="msapplication-TileColor" content="#fdfdd0">
    <meta name="msapplication-square150x150logo" content="public/img/oneOPiQuotation-64x64-t.png">
  </head>
  <body>
    <main>
<?php

// Display quotation
echo $quot->to_html(null, true, '_blank', 'h1');


// Sharing buttons Twitter, Facebook and Google+
$max_length = 140 - 22 - 1;  // 22 for length of short url
$quot_short = htmlspecialchars($quot->to_text_twitter(null, null, $max_length));

echo '      <footer id="sharing-global">
        Partager cette citation&thinsp;:
        <ul>
          <li>
            <a class="twitter-share-button" href="https://twitter.com/share" data-lang="fr" data-text="', $quot_short, '" data-url="', $url, '"',
  (mb_strlen($quot_short) + 21 <= $max_length
   ? ' data-via="OPiCitationJour"'  # ' via @OPiCitationJour': length 21
   : ''), '></a>
          <li>
            <div class="fb-like" data-href="', $url, '" data-layout="button_count" data-share="true" data-show-faces="true"></div>
          <li>
            <div class="g-plus" data-action="share" data-annotation="bubble" data-href="', $url, '" data-width="120"></div>
        </ul>
      </footer>
';

?>
    </main>
<?php if (!isset($_GET['no-link-OPiQuotations'])): ?>
    <footer>
      &rarr;
      <a href="<?php echo $url_site; ?>" target="_blank">D&rsquo;autres citations sur <span>O<span class="surname">Pi</span>Citations</span></a>
    </footer>
  </body>
<?php endif; ?>
</html>
